#!/usr/bin/env python
# -*- coding: utf-8 -*-

import sys
from tornado.web import Application, StaticFileHandler
import tornado.httpserver
import tornado.ioloop
from tornado.options import define, options, parse_command_line
from jinja2 import Environment, FileSystemLoader
from sqlalchemy.orm import scoped_session, sessionmaker
from os.path import dirname, join, isfile
import config
from inventory.models import init_db

try:
    import inventory
    assert inventory  # silence pyflakes
except ImportError:
    sys.path.append(config.project_root)

from inventory.models import engine
from inventory.handlers import IndexHandler, NoDestinationHandler

define('port', default=8080, help='run on the given port', type=int)


class InventoryApp(Application):
    def __init__(self):

        handlers = config.handlers
        settings = config.settings
        

        super(InventoryApp, self).__init__(handlers, **settings)
        self.env = Environment(loader=FileSystemLoader(config.template_path))
        self.db = scoped_session(sessionmaker(bind=engine))
        init_db()
            

def main():
    parse_command_line()
    http_server = tornado.httpserver.HTTPServer(InventoryApp())
    http_server.listen(options.port, '0.0.0.0')

    print('Starting Tornado on http://localhost:{}/'.format(options.port))
    try:
        tornado.ioloop.IOLoop.instance().start()
    except KeyboardInterrupt:
        sys.exit(0)


if __name__ == '__main__':
    main()
