#####################################################################
# import_building.py created 16 Luglio 2013
#
#####################################################################
#
# Copyright (C) 2013 Paolo De Rosa  <paolo.de.rosa@unipi.it>
#
#
# Permission is hereby granted, free of charge, to any person
# obtaining a copy of this software and associated documentation
# files (the "Software"), to deal in the Software without
# restriction, including without limitation the rights to use,
# copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following
# conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.

import csv
import os, sys
from argh import *
from inventory.models import *
from inventory.config import *

# declaring:
@arg('path', default='buildings.csv', help='path of buildings csv file')
def buildings(path):
    try:
        db = scoped_session(sessionmaker(bind=engine))
    except Exception as e:
        sys.exit(e)

    if os.path.isfile(path):
        with open(path, 'rU') as csvfile:
            reader = csv.reader(csvfile, dialect=csv.excel)
            try:

                for row in reader:
                    if not '-' in row[0]:
                        deps = db.query(Department).filter(Department.key==row[4].upper().decode('utf-8'))
                        if deps.count() == 1:
                            building = Building(row[0].replace('/', '').upper(),row[2].decode('utf-8'), deps[0], description=row[3].decode('utf-8'))
                            try:
                                db.add(building)
                                db.commit()
                            except Exception as e:
                                print e
                            
                        
            except csv.Error as e:
                sys.exit('file %s, line %d: %s' % (filename, reader.line_num, e))


@arg('path', default='departments.csv', help='path of departments csv file')
def departments(path):
    try:
        db = scoped_session(sessionmaker(bind=engine))
    except Exception as e:
        sys.exit(e)

    if os.path.isfile(path):
        with open(path, 'rU') as csvfile:
            reader = csv.reader(csvfile, dialect=csv.excel)
            try:

                for row in reader:
                    print row[0]
                    dep = Department(row[0].strip().upper().decode('utf-8'), row[1].decode('utf-8'),row[2].decode('utf-8'), row[3].decode('utf-8'), row[0]+'.unipi.it')
                    try:
                        db.add(dep)
                        db.commit()
                    except Exception as e:
                        print e
                        
            except csv.Error as e:
                sys.exit('file %s, line %d: %s' % (filename, reader.line_num, e))

                

# assembling:

parser = ArghParser()
parser.add_commands([buildings])
parser.add_commands([departments])

# dispatching:

if __name__ == '__main__':
    parser.dispatch()
