from __future__ import division
import math
import urlparse
import urllib

from tornado.web import UIModule

def update_querystring(url, **kwargs):
    base_url = urlparse.urlsplit(url)
    query_args = urlparse.parse_qs(base_url.query)
    query_args.update(kwargs)
    for arg_name, arg_value in kwargs.iteritems():
        if arg_value is None:
            if query_args.has_key(arg_name):
                del query_args[arg_name]

    query_string = urllib.urlencode(query_args, True)     
    return urlparse.urlunsplit((base_url.scheme, base_url.netloc,
        base_url.path, query_string, base_url.fragment))


class EntryModule(UIModule):
    def render(self, entry):
        return self.render_string("modules/entry.html", entry=entry)


class Paginator(UIModule):
    """Pagination links display."""

    def render(self, page, page_size, results_count):
        pages = int(math.ceil(results_count / page_size)) if results_count else 0

        def get_page_url(page):
            # don't allow ?page=1
            if page <= 1:
                page = None
            return update_querystring(self.request.uri, page=page)

        next = page + 1 if page < pages else None
        previous = page - 1 if page > 1 else None
            
        return  self.render_string('../templates/modules/pagination.html', page=page, pages=pages, next=next,
            previous=previous, get_page_url=get_page_url)


class Navigator(UIModule):

    def render(self, site):

        def get_nav_url(site):
            if site:
                return update_querystring(self.request.uri, site=site)

            
        return self.render_string('../templates/modules/nav.html', get_nav_url=get_nav_url, site=site)


class FacetsWidget(UIModule):

    def render(self, response, site, cat):

        def get_facet_url(param, value):
            kwargs = {param:value}
            return update_querystring(self.request.uri, **kwargs)

            
        return self.render_string('../templates/modules/widget.html', response=response, get_facet_url=get_facet_url, site=site, cat=cat)

class Widget(UIModule):

    def render(self, response):
        return self.render_string('../templates/modules/widget.html', response=response)

class NewsWidget(UIModule):

    def render(self, news):
        return self.render_string('../templates/modules/newsWidget.html', news=news)

class ShortcutsWidget(UIModule):

    def render(self, shortcuts):
        return self.render_string('../templates/modules/shortcutsWidget.html', shortcuts=shortcuts)

class ChartWidget(UIModule):

    def render(self, chart):
        return self.render_string('../templates/modules/chartWidget.html', chart=chart)
