#####################################################################
# model.py created 12 Luglio 2013
#
#####################################################################
#
# Copyright (C) 2013 Paolo De Rosa  <paolo.de.rosa@unipi.it>
#
#
# Permission is hereby granted, free of charge, to any person
# obtaining a copy of this software and associated documentation
# files (the "Software"), to deal in the Software without
# restriction, including without limitation the rights to use,
# copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following
# conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.

from sqlalchemy import create_engine
from sqlalchemy.orm import relationship, backref
from sqlalchemy.orm import scoped_session, sessionmaker
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy import Column, Integer, String, DateTime, Boolean, Unicode, ForeignKey, LargeBinary
from jinja2 import Environment, FileSystemLoader
from tornado.web import RequestHandler, HTTPError
from jinja2.exceptions import TemplateNotFound
from uuid import NAMESPACE_DNS, uuid5

from inventory.config import sqla_uri, sqla_params, URL, template_path

import StringIO
import qrcode

engine = create_engine(sqla_uri, **sqla_params)
db_session = scoped_session(sessionmaker(autocommit=False,
                                         autoflush=False,
                                         bind=engine))
Base = declarative_base()
Base.query = db_session.query_property()

class IBaseMixin(object):
  tmpl = None

  def render(self, **kwargs):
    if self.tmpl:
      env = Environment(loader=FileSystemLoader(template_path))
      try:
        template = env.get_template(self.tmpl)
      except TemplateNotFound:
        raise HTTPError(404)
      return template.render(kwargs, me=self)
    return None
    
  @property
  def url(self):
    return "%s/%s" % (URL, self.oid)

  @property
  def uuid(self):
    return str(uuid5(NAMESPACE_DNS, self.url.encode('ascii')))

  @property
  def oid(self):
    if self.parent:
      return "%s-%s" % (self.parent.oid, self.key)
    return self.key

  @property
  def _qrcode(self):
    qcode = StringIO.StringIO()
    img = qrcode.make(self.url)
    img.save(qcode, "PNG")
    result = qcode.getvalue().encode("base64")
    qcode.close()
    return result

  def __repr__(self):
    return "<%s('oid:%s','key:%s', 'id:%s')>" % (str(self.__class__).split('.')[-1].strip("<>"), self.oid, self.key, self.id)



from user import *
from department import *
from building import *
from rack import *
from device import *


def init_db():
  Base.metadata.create_all(bind=engine)


